@@ -402,6 +402,14 @@ sub delete_plot {
     return $self;
 }
 
+sub Lens {
+    my ($self, $key) = @_;
+    require Gnuplot::Builder::Lens;
+    return Gnuplot::Builder::Lens->new(
+        "get_option", "set_option", $key
+    );
+}
+
 1;
 
 __END__
@@ -1344,6 +1352,27 @@ When you evaluate a C<$builder> as a string, it executes C<< $builder->to_string
 
     "$builder" eq $builder->to_string;
 
+=head1 Data::Focus COMPATIBLITY
+
+L<Gnuplot::Builder::Script> implements C<Lens()> method, so you can use L<Data::Focus> to access its attributes.
+
+The C<Lens()> method creates a L<Data::Focus::Lens> object for accessing gnuplot options via C<get_option()> and C<set_option()>.
+
+Note that the lens calls C<get_option()> always in scalar context.
+
+    use Data::Focus qw(focus);
+    
+    my $scalar = focus($builder)->get("xrange");
+    ## same as: my $scalar = scalar($builder->get_option("xrange"));
+        
+    my @list = focus($builder)->list("style");
+    ## same as: my @list = scalar($builder->get_option("style"));
+        
+    focus($builder)->set(xrange => '[10:100]');
+    ## same as: $builder->set_option(xrange => '[10:100]');
+
+This results in a surprising behavior if you pass array-refs to C<set()> method. Use with care.
+
 =head1 SEE ALSO
 
 L<Gnuplot::Builder::Dataset>
